/* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
/** library for UART communication (API)
 *  @file
 *  @author King Kévin <kingkevin@cuvoodoo.info>
 *  @date 2016-2020
 *  @note peripherals used: USART @ref uart
 */
#pragma once

/** setup UART peripheral */
void uart_setup(void);
/** send character over UART (blocking)
 *  @param[in] c character to send
 *  @note blocks until character transmission started */
void uart_putchar_blocking(char c);
/** ensure all data has been transmitted (blocking)
 *  @note block until all data has been transmitted
 */
void uart_flush(void);
/** send character over UART (non-blocking)
 *  @param[in] c character to send
 *  @note blocks if transmit buffer is full, else puts in buffer and returns
 */
void uart_putchar_nonblocking(char c);
